@@ -25,6 +25,12 @@ try:
 except ImportError:
     from sqlalchemy.dialects.postgresql import ARRAY
 
+# SQLAlchemy 1.3.11+
+try:
+    from sqlalchemy import Computed
+except ImportError:
+    Computed = None
+
 # Conditionally import Geoalchemy2 to enable reflection support
 try:
     import geoalchemy2  # noqa: F401
@@ -101,7 +107,12 @@ class Model(object):
                 if supercls is Enum:
                     kw['name'] = coltype.name
 
-                new_coltype = coltype.adapt(supercls)
+                try:
+                    new_coltype = coltype.adapt(supercls)
+                except TypeError:
+                    # If the adaptation fails, don't try again
+                    break
+
                 for key, value in kw.items():
                     setattr(new_coltype, key, value)
 
@@ -137,7 +148,10 @@ class Model(object):
         for column in self.table.columns:
             collector.add_import(column.type)
             if column.server_default:
-                collector.add_literal_import('sqlalchemy', 'text')
+                if Computed and isinstance(column.server_default, Computed):
+                    collector.add_literal_import('sqlalchemy', 'Computed')
+                else:
+                    collector.add_literal_import('sqlalchemy', 'text')
 
             if isinstance(column.type, ARRAY):
                 collector.add_import(column.type.item_type.__class__)
@@ -476,30 +490,35 @@ class CodeGenerator(object):
     @classmethod
     def render_column_type(cls, coltype):
         args = []
-        if isinstance(coltype, Enum):
-            args.extend(repr(arg) for arg in coltype.enums)
-            if coltype.name is not None:
-                args.append('name={0!r}'.format(coltype.name))
-        else:
-            # All other types
-            argspec = cls._getargspec_init(coltype.__class__.__init__)
-            defaults = dict(zip(argspec.args[-len(argspec.defaults or ()):],
-                                argspec.defaults or ()))
-            missing = object()
-            use_kwargs = False
-            for attr in argspec.args[1:]:
-                # Remove annoyances like _warn_on_bytestring
-                if attr.startswith('_'):
-                    continue
+        kwargs = OrderedDict()
+        argspec = cls._getargspec_init(coltype.__class__.__init__)
+        defaults = dict(zip(argspec.args[-len(argspec.defaults or ()):],
+                            argspec.defaults or ()))
+        missing = object()
+        use_kwargs = False
+        for attr in argspec.args[1:]:
+            # Remove annoyances like _warn_on_bytestring
+            if attr.startswith('_'):
+                continue
 
-                value = getattr(coltype, attr, missing)
-                default = defaults.get(attr, missing)
-                if value is missing or value == default:
-                    use_kwargs = True
-                elif use_kwargs:
-                    args.append('{0}={1}'.format(attr, repr(value)))
-                else:
-                    args.append(repr(value))
+            value = getattr(coltype, attr, missing)
+            default = defaults.get(attr, missing)
+            if value is missing or value == default:
+                use_kwargs = True
+            elif use_kwargs:
+                kwargs[attr] = repr(value)
+            else:
+                args.append(repr(value))
+
+        if argspec.varargs and hasattr(coltype, argspec.varargs):
+            varargs_repr = [repr(arg) for arg in getattr(coltype, argspec.varargs)]
+            args.extend(varargs_repr)
+
+        if isinstance(coltype, Enum) and coltype.name is not None:
+            kwargs['name'] = repr(coltype.name)
+
+        for key, value in kwargs.items():
+            args.append('{}={}'.format(key, value))
 
         rendered = coltype.__class__.__name__
         if args:
@@ -568,7 +587,16 @@ class CodeGenerator(object):
         elif has_index:
             column.index = True
             kwarg.append('index')
-        if column.server_default:
+
+        if Computed and isinstance(column.server_default, Computed):
+            expression = self._get_compiled_expression(column.server_default.sqltext)
+
+            persist_arg = ''
+            if column.server_default.persisted is not None:
+                persist_arg = ', persisted={}'.format(column.server_default.persisted)
+
+            server_default = 'Computed({!r}{})'.format(expression, persist_arg)
+        elif column.server_default:
             # The quote escaping does not cover pathological cases but should mostly work
             default_expr = self._get_compiled_expression(column.server_default.arg)
             if '\n' in default_expr:
@@ -585,7 +613,7 @@ class CodeGenerator(object):
             [repr(x) for x in column.constraints] +
             ['{0}={1}'.format(k, repr(getattr(column, k))) for k in kwarg] +
             ([server_default] if server_default else []) +
-            (['comment={!r}'.format(comment)] if comment else [])
+            (['comment={!r}'.format(comment)] if comment and not self.nocomments else [])
         ))
 
     def render_relationship(self, relationship):
